@@ -2,6 +2,13 @@
 
 """Top-level package for Explanation Toolkit."""
 
+from pyreal.realapp.realapp import RealApp
+
 __author__ = "MIT Data To AI Lab"
 __email__ = "dailabmit@gmail.com"
-__version__ = "0.3.1.1"
+__version__ = "0.4.0"
+
+
+__all__ = [
+    "RealApp",
+]
