@@ -2,6 +2,8 @@ import pandas as pd
 from sklearn import tree
 
 from pyreal.explainers import DecisionTreeExplainerBase
+from pyreal.types.explanations.decision_tree import DecisionTreeExplanation
+from pyreal.types.explanations.feature_based import FeatureImportanceExplanation
 
 
 class SurrogateDecisionTree(DecisionTreeExplainerBase):
@@ -56,11 +58,11 @@ class SurrogateDecisionTree(DecisionTreeExplainerBase):
 
         if self.explainer is None:
             raise AttributeError(
-                "Instance has no explainer. Please fit the explainer             before producing"
+                "Instance has no explainer. Please fit the explainer before producing"
                 " explanations."
             )
 
-        return self.explainer
+        return DecisionTreeExplanation(self.explainer)
 
     def produce_importances(self):
         """
@@ -77,4 +79,4 @@ class SurrogateDecisionTree(DecisionTreeExplainerBase):
 
         features = self.return_features()
         importances = pd.DataFrame(self.explainer.feature_importances_[None, :], columns=features)
-        return importances
+        return FeatureImportanceExplanation(importances)
