@@ -118,19 +118,21 @@ class GlobalFeatureImportance(GlobalFeatureImportanceBase):
            Filepath to the pickled model to explain, or model object with .predict() function
         x_train_orig (dataframe of shape (n_instances, x_orig_feature_count)):
            The training set for the explainer
-        e_algorithm (string, one of ["shap"]):
+        e_algorithm (string, one of ["shap", "permutation"]):
            Explanation algorithm to use. If none, one will be chosen automatically based on model
            type
+        shap_type (string, one of ["kernel", "linear"]):
+            Type of shap algorithm to use, if e_algorithm="shap".
         **kwargs: see LocalFeatureContributionsBase args
     """
 
-    def __init__(self, model, x_train_orig, e_algorithm=None, **kwargs):
+    def __init__(self, model, x_train_orig, e_algorithm=None, shap_type=None, **kwargs):
         if e_algorithm is None:
             e_algorithm = choose_algorithm()
         self.base_global_feature_importance = None
         if e_algorithm == "shap":
             self.base_global_feature_importance = ShapFeatureImportance(
-                model, x_train_orig, **kwargs
+                model, x_train_orig, shap_type=shap_type, **kwargs
             )
         if e_algorithm == "permutation":
             self.base_global_feature_importance = PermutationFeatureImportance(
